# frozen_string_literal: true

# Controller for managing Roles
class UserRolesController < ApplicationController
  include Hydra::RoleManagement::UserRolesBehavior

  def create
    authorize! :add_user, @role
    user = find_user

    redirect_to role_management.role_path(@role),
                flash: { error: "Invalid user #{params[:user_key]}" } unless user
    user.roles << @role
    user.add_workflow_role(@role) if user.save!
    redirect_to role_management.role_path(@role)
  end

  def destroy
    authorize! :remove_user, @role
    user = ::User.find(params[:id])
    redirect_to role_management.role_path(@role),
                flash: { error: "Invalid user #{params[:user_key]}" } unless user

    user.remove_workflow_role(@role) if remove_workflow_roles?(user)
    @role.users.delete(user)

    redirect_to role_management.role_path(@role)
  end

  private

  def remove_workflow_roles?(user)
    user.publication_manager? || user.crc_manager? || user.crc_group_manager? || user.crc_group_member?
  end
end
